@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # filelines.py
 #
@@ -20,6 +21,7 @@
 #
 """Functions on reading and writing files by line."""
 import os
+import sys
 
 import atomicwrites
 from atomicwrites import atomic_write
@@ -38,6 +40,7 @@ def get_line_matches(input_file: str,
     :parameter pattern: the pattern that needs to be searched.
     :parameter max_occurrencies: the maximum number of expected occurrencies.
          Defaults to ``0`` which means that all occurrencies will be matched.
+         This parameter is limited by the platform (``sys.maxsize``).
     :parameter loose_matching: ignore leading and trailing whitespace
          characters for both pattern and matched strings. Defaults to ``True``.
     :parameter keep_all_lines: if set to ``True`` returns the whole file content
@@ -61,16 +64,19 @@ def get_line_matches(input_file: str,
     .. note::
          Line numbers start from ``1``.
     """
-    if max_occurrencies < 0:
+    if max_occurrencies < 0 or max_occurrencies > sys.maxsize:
         raise ValueError
 
     occurrency_counter: float = 0.0
     occurrency_matches: dict = dict()
     lines: list = list()
+    lns: str
     line_original: str
 
     if max_occurrencies == 0:
-        max_occurrencies = float('inf')
+        # See
+        # https://docs.python.org/3/whatsnew/3.0.html#integers
+        max_occurrencies = sys.maxsize
     if loose_matching:
         pattern = pattern.strip()
 
@@ -92,9 +98,9 @@ def get_line_matches(input_file: str,
             line = f.readline()
             line_counter += 1
 
-    lines = ''.join(lines)
+    lns = ''.join(lines)
 
-    return occurrency_matches, lines
+    return occurrency_matches, lns
 
 
 def insert_string_at_line(input_file: str,
@@ -137,7 +143,7 @@ def insert_string_at_line(input_file: str,
         raise ValueError
 
     with open(input_file, 'r') as f:
-        lines: str = f.readlines()
+        lines: list = f.readlines()
 
     line_counter: int = 1
     lines_length: int = len(lines)
@@ -227,7 +233,7 @@ def remove_line_interval(input_file: str, delete_line_from: int,
         raise ValueError
 
     with open(input_file, 'r') as f:
-        lines: str = f.readlines()
+        lines: list = f.readlines()
     lines_length: int = len(lines)
 
     # Invalid line ranges.
